@@ -1,13 +1,14 @@
 
+import hashlib
+import random
+from functools import partial
+
 from couchdbcurl import Server, Document, ResourceConflict, ResourceNotFound
 from django.conf import settings
 
-import hashlib
-import random
-
 from translit import slugify
 
-def db(name = None):
+def db(name=None, partitioning_data=None):
     """name is a key in settings.COUCHDB. If None, returns default database.
     Examples::
     
@@ -21,6 +22,11 @@ def db(name = None):
           'server': 'http://node1:5984',
           'database': 'database2',
         },
+        'partitioned_db': {
+          'server': 'http://node1:5984',
+          'database': 'database_%s',
+          'partitioning_function': lambda dbname, params: dbname % params.strftime('%Y'),
+        },
       }
 
     Next, you may access django databases as::
@@ -30,8 +36,10 @@ def db(name = None):
       django_couch.db('db1') # Database1 (key - db1) @ http://node1:5984/database1
       django_couch.db('db2') # Database2 (key - db2) @ http://node1:5984/database2
 
-          
-    
+      django_couch.db('partitioned_db')() # Database3 (key - partitioned_db) @ http://node1:5984/partitioned_db_2012
+      django_couch.db('partitioned_db')(date(2013, 1, 1)) # Database3 (key - partitioned_db) @ http://node1:5984/partitioned_db_2013
+      
+      
     """
     
     if not name:
@@ -39,10 +47,16 @@ def db(name = None):
         if len(default) != 1:
             raise Exception("There are no/multiple default database. Please, check settings.COUCHDB value.")
         name = default[0]
-        
+    
     server = Server(settings.COUCHDB[name]['server'])
     
-    return server[settings.COUCHDB[name]['database']]
+    row = settings.COUCHDB[name]
+    dbname = settings.COUCHDB[name]['database']
+    
+    if 'partitioning_function' in row:
+        dbname = row['partitioning_function'](dbname, partitioning_data)
+    
+    return server[dbname]
 
 ## server = Server(settings.COUCHDB_ADDR)
 
@@ -220,7 +234,11 @@ class CouchMiddleware:
       
     def process_request(self, request):
         for dbname in settings.COUCHDB:
-            setattr(request, dbname, db(dbname))
+            
+            if 'partitioning_function' in settings.COUCHDB[dbname]:
+                setattr(request, dbname, partial(db, dbname))
+            else:
+                setattr(request, dbname, db(dbname))
         request._db = db
 
         
